**Example 1: test**



Input: 

```
tccli emr DescribeResourceSchedule --cli-unfold-argument  \
    --InstanceId xx
```

Output: 
```
{
    "Response": {
        "FSInfo": "xx",
        "CSInfo": "xx",
        "Scheduler": "xx",
        "OpenSwitch": true,
        "RequestId": "xx"
    }
}
```

